pub struct GetGifsByResponse {
pub data: Vec<Gif>,
pub meta: Option<Meta>,
pub pagination: Option<Pagination>,
}Fields
data: Vec<Gif>meta: Option<Meta>The Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.
pagination: Option<Pagination>The Pagination Object contains information relating to the number of total results available as well as the number of results fetched and their relative positions.