pub struct Gif {Show 20 fields
pub bitly_url: String,
pub content_url: String,
pub create_datetime: Option<DateTime<Utc>>,
pub embded_url: String,
pub featured_tags: Vec<String>,
pub id: String,
pub images: Option<Images>,
pub import_datetime: Option<DateTime<Utc>>,
pub rating: String,
pub slug: String,
pub source: String,
pub source_post_url: String,
pub source_tld: String,
pub tags: Vec<String>,
pub trending_datetime: Option<DateTime<Utc>>,
pub type_: Option<Type>,
pub update_datetime: Option<DateTime<Utc>>,
pub url: String,
pub user: Option<User>,
pub username: String,
}Fields
bitly_url: StringThe unique bit.ly URL for this GIF
content_url: StringThe unique bit.ly URL for this GIF
create_datetime: Option<DateTime<Utc>>The date this GIF was added to the GIPHY database.
embded_url: StringThe unique bit.ly URL for this GIF
An array of featured tags for this GIF (Note: Not available when using the Public Beta Key)
id: StringThe unique bit.ly URL for this GIF
images: Option<Images>An object containing data for various available formats and sizes of this GIF.
import_datetime: Option<DateTime<Utc>>The date this GIF was added to the GIPHY database.
rating: StringThe unique bit.ly URL for this GIF
slug: StringThe unique bit.ly URL for this GIF
source: StringThe unique bit.ly URL for this GIF
source_post_url: StringThe unique bit.ly URL for this GIF
source_tld: StringThe unique bit.ly URL for this GIF
An array of featured tags for this GIF (Note: Not available when using the Public Beta Key)
trending_datetime: Option<DateTime<Utc>>The date this GIF was added to the GIPHY database.
type_: Option<Type>Type of the gif. By default, this is almost always gif
update_datetime: Option<DateTime<Utc>>The date this GIF was added to the GIPHY database.
url: StringThe unique bit.ly URL for this GIF
user: Option<User>The User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
username: StringThe unique bit.ly URL for this GIF