pub struct Images {Show 20 fields
pub downsized: Option<LoopingAllOf>,
pub downsized_large: Option<LoopingAllOf>,
pub downsized_medium: Option<LoopingAllOf>,
pub downsized_small: Option<LoopingAllOf>,
pub downsized_still: Option<LoopingAllOf>,
pub fixed_height: Option<LoopingAllOf>,
pub fixed_height_downsampled: Option<LoopingAllOf>,
pub fixed_height_small: Option<LoopingAllOf>,
pub fixed_height_small_still: Option<LoopingAllOf>,
pub fixed_height_still: Option<LoopingAllOf>,
pub fixed_width: Option<LoopingAllOf>,
pub fixed_width_downsampled: Option<LoopingAllOf>,
pub fixed_width_small: Option<LoopingAllOf>,
pub fixed_width_small_still: Option<LoopingAllOf>,
pub fixed_width_still: Option<LoopingAllOf>,
pub looping: Option<LoopingAllOf>,
pub original: Option<LoopingAllOf>,
pub original_still: Option<LoopingAllOf>,
pub preview: Option<LoopingAllOf>,
pub preview_gif: Option<LoopingAllOf>,
}Expand description
An object containing data for various available formats and sizes of this GIF.
Fields
downsized: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
downsized_large: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
downsized_medium: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
downsized_small: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
downsized_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_height: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_height_downsampled: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_height_small: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_height_small_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_height_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_width: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_width_downsampled: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_width_small: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_width_small_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
fixed_width_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
looping: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
original: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
original_still: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
preview: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.
preview_gif: Option<LoopingAllOf>An object containing data for various available formats and sizes of this GIF.