pub struct Meta {
pub msg: String,
pub response_id: String,
pub status: i64,
}Expand description
The Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.
Fields
msg: StringThe Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.
response_id: StringThe Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.
status: i64The Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.