pub struct RandomGifResponse {
pub data: Option<Gif>,
pub meta: Option<Meta>,
}Fields
data: Option<Gif>meta: Option<Meta>The Meta Object contains basic information regarding the request, whether it was successful, and the response given by the API. Check responses to see a description of types of response codes the API might give you under different cirumstances.