pub struct User {
pub avatar_url: String,
pub banner_url: String,
pub display_name: String,
pub profile_url: String,
pub twitter: String,
pub username: String,
}Expand description
The User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
Fields
avatar_url: StringThe User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
The User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
display_name: StringThe User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
profile_url: StringThe User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
twitter: StringThe User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.
username: StringThe User Object contains information about the user associated with a GIF and URLs to assets such as that user’s avatar image, profile, and more.